@@ -1,74 +1,14 @@
 import asyncio
-import aiohttp
 import collections
 import logging
-import pytest
-import re
 import sys
-import warnings
+
+import pytest
+
+import aiohttp
 from aiohttp import web
-from aiohttp.test_utils import (
-    loop_context, unused_port
-)
 
-
-class _AssertWarnsContext:
-    """A context manager used to implement TestCase.assertWarns* methods."""
-
-    def __init__(self, expected, expected_regex=None):
-        self.expected = expected
-        if expected_regex is not None:
-            expected_regex = re.compile(expected_regex)
-        self.expected_regex = expected_regex
-        self.obj_name = None
-
-    def __enter__(self):
-        # The __warningregistry__'s need to be in a pristine state for tests
-        # to work properly.
-        for v in sys.modules.values():
-            if getattr(v, '__warningregistry__', None):
-                v.__warningregistry__ = {}
-        self.warnings_manager = warnings.catch_warnings(record=True)
-        self.warnings = self.warnings_manager.__enter__()
-        warnings.simplefilter("always", self.expected)
-        return self
-
-    def __exit__(self, exc_type, exc_value, tb):
-        self.warnings_manager.__exit__(exc_type, exc_value, tb)
-        if exc_type is not None:
-            # let unexpected exceptions pass through
-            return
-        try:
-            exc_name = self.expected.__name__
-        except AttributeError:
-            exc_name = str(self.expected)
-        first_matching = None
-        for m in self.warnings:
-            w = m.message
-            if not isinstance(w, self.expected):
-                continue
-            if first_matching is None:
-                first_matching = w
-            if (self.expected_regex is not None and
-                    not self.expected_regex.search(str(w))):
-                continue
-            # store warning for later retrieval
-            self.warning = w
-            self.filename = m.filename
-            self.lineno = m.lineno
-            return
-        # Now we simply try to choose a helpful failure message
-        if first_matching is not None:
-            __tracebackhide__ = True
-            assert 0, '"{}" does not match "{}"'.format(
-                self.expected_regex.pattern, str(first_matching))
-        if self.obj_name:
-            __tracebackhide__ = True
-            assert 0, "{} not triggered by {}".format(exc_name,
-                                                      self.obj_name)
-        else:
-            __tracebackhide__ = True
-            assert 0, "{} not triggered".format(exc_name)
+pytest_plugins = 'aiohttp.pytest_plugin'
 
 
 _LoggingWatcher = collections.namedtuple("_LoggingWatcher",
@@ -137,28 +77,13 @@ class _AssertLogsContext:
                                self.logger.name))
 
 
-@pytest.yield_fixture
-def warning():
-    yield _AssertWarnsContext
-
-
 @pytest.yield_fixture
 def log():
     yield _AssertLogsContext
 
 
-# add the unused_port and loop fixtures
-pytest.fixture(unused_port)
-
-
 @pytest.yield_fixture
-def loop():
-    with loop_context() as loop:
-        yield loop
-
-
-@pytest.yield_fixture
-def create_server(loop):
+def create_server(loop, unused_port):
     app = handler = srv = None
 
     @asyncio.coroutine
@@ -178,10 +103,15 @@ def create_server(loop):
 
     @asyncio.coroutine
     def finish():
-        yield from handler.finish_connections()
-        yield from app.finish()
-        srv.close()
-        yield from srv.wait_closed()
+        if srv:
+            srv.close()
+            yield from srv.wait_closed()
+        if app:
+            yield from app.shutdown()
+        if handler:
+            yield from handler.finish_connections()
+        if app:
+            yield from app.cleanup()
 
     loop.run_until_complete(finish())
 
@@ -196,6 +126,12 @@ class Client:
     def close(self):
         self._session.close()
 
+    def request(self, method, path, **kwargs):
+        while path.startswith('/'):
+            path = path[1:]
+        url = self._url + path
+        return self._session.request(method, url, **kwargs)
+
     def get(self, path, **kwargs):
         while path.startswith('/'):
             path = path[1:]
@@ -239,38 +175,8 @@ def create_app_and_client(create_server, loop):
         return app, client
 
     yield maker
-    client.close()
-
-
-@pytest.mark.tryfirst
-def pytest_pycollect_makeitem(collector, name, obj):
-    if collector.funcnamefilter(name):
-        if not callable(obj):
-            return
-        item = pytest.Function(name, parent=collector)
-        if 'run_loop' in item.keywords:
-            return list(collector._genfunctions(name, obj))
-
-
-@pytest.mark.tryfirst
-def pytest_pyfunc_call(pyfuncitem):
-    """
-    Run asyncio marked test functions in an event loop instead of a normal
-    function call.
-    """
-    if 'run_loop' in pyfuncitem.keywords:
-        funcargs = pyfuncitem.funcargs
-        loop = funcargs['loop']
-        testargs = {arg: funcargs[arg]
-                    for arg in pyfuncitem._fixtureinfo.argnames}
-        loop.run_until_complete(pyfuncitem.obj(**testargs))
-        return True
-
-
-def pytest_runtest_setup(item):
-    if 'run_loop' in item.keywords and 'loop' not in item.fixturenames:
-        # inject an event loop fixture for all async tests
-        item.fixturenames.append('loop')
+    if client is not None:
+        client.close()
 
 
 def pytest_ignore_collect(path, config):
