@@ -1,11 +1,6 @@
-import pytest
-
 import aiohttp
-from aiohttp import web
-from aiohttp import helpers
+from aiohttp import helpers, web
 
-
-@pytest.mark.run_loop
 async def test_server_ws_async_for(loop, create_server):
     closed = helpers.create_future(loop)
 
@@ -13,7 +8,7 @@ async def test_server_ws_async_for(loop, create_server):
         ws = web.WebSocketResponse()
         await ws.prepare(request)
         async for msg in ws:
-            assert msg.tp == aiohttp.MsgType.text
+            assert msg.type == aiohttp.MsgType.TEXT
             s = msg.data
             ws.send_str(s + '/answer')
         await ws.close()
@@ -28,7 +23,7 @@ async def test_server_ws_async_for(loop, create_server):
     for item in items:
         resp.send_str(item)
         msg = await resp.receive()
-        assert msg.tp == aiohttp.MsgType.text
+        assert msg.type == aiohttp.MsgType.TEXT
         assert item + '/answer' == msg.data
 
     await resp.close()
