@@ -3,21 +3,17 @@ import os
 import pathlib
 import re
 import unittest
-from collections.abc import Sized, Container, Iterable, Mapping, MutableMapping
+from collections.abc import Container, Iterable, Mapping, MutableMapping, Sized
 from urllib.parse import unquote
+
 import aiohttp.web
 from aiohttp import hdrs
-from aiohttp.web import (UrlDispatcher, Response,
-                         HTTPMethodNotAllowed, HTTPNotFound,
-                         HTTPCreated)
-from aiohttp.web_urldispatcher import (_defaultExpectHandler,
-                                       DynamicRoute,
-                                       PlainRoute,
-                                       SystemRoute,
-                                       ResourceRoute,
-                                       AbstractResource,
-                                       View)
 from aiohttp.test_utils import make_mocked_request
+from aiohttp.web import (HTTPMethodNotAllowed, HTTPNotFound, Response,
+                         UrlDispatcher)
+from aiohttp.web_urldispatcher import (AbstractResource, DynamicRoute,
+                                       PlainRoute, ResourceRoute, SystemRoute,
+                                       View, _defaultExpectHandler)
 
 
 class TestUrlDispatcher(unittest.TestCase):
@@ -41,28 +37,6 @@ class TestUrlDispatcher(unittest.TestCase):
 
         return handler
 
-    def test_system_route(self):
-        route = SystemRoute(HTTPCreated(reason='test'))
-        self.assertIsNone(route.match('any'))
-        with self.assertRaises(RuntimeError):
-            route.url()
-        self.assertEqual("<SystemRoute 201: test>", repr(route))
-        self.assertEqual(201, route.status)
-        self.assertEqual('test', route.reason)
-
-    def test_register_route(self):
-        handler = self.make_handler()
-        route = PlainRoute('GET', handler, 'test', '/handler/to/path')
-        self.router.register_route(route)
-
-        req = self.make_request('GET', '/handler/to/path')
-        info = self.loop.run_until_complete(self.router.resolve(req))
-        self.assertIsNotNone(info)
-        self.assertEqual(0, len(info))
-        self.assertIs(route, info.route)
-        self.assertIs(handler, info.handler)
-        self.assertEqual(info.route.name, 'test')
-
     def test_register_route_checks(self):
         self.assertRaises(
             AssertionError, self.router.register_route, object())
@@ -82,6 +56,24 @@ class TestUrlDispatcher(unittest.TestCase):
                            '/handler/to/path')
         self.router.register_route(route)
 
+    def test_register_uncommon_http_methods(self):
+        handler = self.make_handler()
+
+        uncommon_http_methods = {
+            'PROPFIND',
+            'PROPPATCH',
+            'COPY',
+            'LOCK',
+            'UNLOCK'
+            'MOVE',
+            'SUBSCRIBE',
+            'UNSUBSCRIBE',
+            'NOTIFY'
+        }
+
+        for method in uncommon_http_methods:
+            PlainRoute(method, handler, 'url', '/handler/to/path')
+
     def test_add_route_root(self):
         handler = self.make_handler()
         self.router.add_route('GET', '/', handler)
@@ -112,6 +104,56 @@ class TestUrlDispatcher(unittest.TestCase):
         self.assertIs(handler, info.handler)
         self.assertIsNone(info.route.name)
 
+    def test_add_route_with_add_get_shortcut(self):
+        handler = self.make_handler()
+        self.router.add_get('/handler/to/path', handler)
+        req = self.make_request('GET', '/handler/to/path')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual(0, len(info))
+        self.assertIs(handler, info.handler)
+        self.assertIsNone(info.route.name)
+
+    def test_add_route_with_add_post_shortcut(self):
+        handler = self.make_handler()
+        self.router.add_post('/handler/to/path', handler)
+        req = self.make_request('POST', '/handler/to/path')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual(0, len(info))
+        self.assertIs(handler, info.handler)
+        self.assertIsNone(info.route.name)
+
+    def test_add_route_with_add_put_shortcut(self):
+        handler = self.make_handler()
+        self.router.add_put('/handler/to/path', handler)
+        req = self.make_request('PUT', '/handler/to/path')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual(0, len(info))
+        self.assertIs(handler, info.handler)
+        self.assertIsNone(info.route.name)
+
+    def test_add_route_with_add_patch_shortcut(self):
+        handler = self.make_handler()
+        self.router.add_patch('/handler/to/path', handler)
+        req = self.make_request('PATCH', '/handler/to/path')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual(0, len(info))
+        self.assertIs(handler, info.handler)
+        self.assertIsNone(info.route.name)
+
+    def test_add_route_with_add_delete_shortcut(self):
+        handler = self.make_handler()
+        self.router.add_delete('/handler/to/path', handler)
+        req = self.make_request('DELETE', '/handler/to/path')
+        info = self.loop.run_until_complete(self.router.resolve(req))
+        self.assertIsNotNone(info)
+        self.assertEqual(0, len(info))
+        self.assertIs(handler, info.handler)
+        self.assertIsNone(info.route.name)
+
     def test_add_with_name(self):
         handler = self.make_handler()
         self.router.add_route('GET', '/handler/to/path', handler,
@@ -561,9 +603,20 @@ class TestUrlDispatcher(unittest.TestCase):
             self.router.add_route('GET', 'invalid_path', handler)
 
     def test_add_route_invalid_method(self):
-        with self.assertRaises(ValueError):
-            handler = self.make_handler()
-            self.router.add_route('INVALID_METHOD', '/path', handler)
+
+        sample_bad_methods = {
+            'BAD METHOD',
+            'B@D_METHOD',
+            '[BAD_METHOD]',
+            '{BAD_METHOD}',
+            '(BAD_METHOD)',
+            'B?D_METHOD',
+        }
+
+        for bad_method in sample_bad_methods:
+            with self.assertRaises(ValueError):
+                handler = self.make_handler()
+                self.router.add_route(bad_method, '/path', handler)
 
     def fill_routes(self):
         route1 = self.router.add_route('GET', '/plain', self.make_handler())
